@@ -3,8 +3,8 @@ from cc_py_commons.schemas.camel_case_schema import CamelCaseSchema
 
 class FreightHubContactSchema(CamelCaseSchema):
   contact_name = fields.String()
-  contact_phone = fields.String()
-  contact_fax = fields.String()
+  contact_phone = fields.String(allow_none=True)
+  contact_fax = fields.String(allow_none=True)
   contact_email = fields.String()
   company_name = fields.String()
-  user_id = fields.String()
\ No newline at end of file
+  user_id = fields.String(allow_none=True)
\ No newline at end of file
