@@ -5,6 +5,6 @@ class LocationSchema(CamelCaseSchema):
 
   city = fields.String()
   state = fields.String()
-  postcode = fields.String()
-  county = fields.String() 
-  country = fields.String()
\ No newline at end of file
+  postcode = fields.String(allow_none=True)
+  county = fields.String(allow_none=True) 
+  country = fields.String(allow_none=True)
\ No newline at end of file
